Index: /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualBoxManager.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualBoxManager.cpp	(revision 91663)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/manager/UIVirtualBoxManager.cpp	(revision 91664)
@@ -867,8 +867,21 @@
     /* Initialize variables: */
 #ifdef VBOX_WS_MAC
-    const QString strTmpFile = ::darwinResolveAlias(strFileName);
+    QString strTmpFile = ::darwinResolveAlias(strFileName);
 #else
-    const QString strTmpFile = strFileName;
+    QString strTmpFile = strFileName;
 #endif
+
+    /* If there is no file-name passed,
+     * check if cloud stuff focused currently: */
+    bool fOCIByDefault = false;
+    if (   strTmpFile.isEmpty()
+        && (   m_pWidget->isSingleCloudProviderGroupSelected()
+            || m_pWidget->isSingleCloudProfileGroupSelected()
+            || m_pWidget->isCloudMachineItemSelected()))
+    {
+        /* We can generate cloud hints as well: */
+        fOCIByDefault = true;
+        strTmpFile = m_pWidget->fullGroupName();
+    }
 
     /* Lock the action preventing cascade calls: */
@@ -880,5 +893,5 @@
     /* Use the "safe way" to open stack of Mac OS X Sheets: */
     QWidget *pWizardParent = windowManager().realParentWindow(this);
-    UINativeWizardPointer pWizard = new UIWizardImportApp(pWizardParent, false /* OCI by default? */, strTmpFile);
+    UINativeWizardPointer pWizard = new UIWizardImportApp(pWizardParent, fOCIByDefault, strTmpFile);
     windowManager().registerNewParent(pWizard, pWizardParent);
     pWizard->exec();
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportApp.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportApp.cpp	(revision 91663)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportApp.cpp	(revision 91664)
@@ -278,5 +278,5 @@
         {
             if (m_fImportFromOCIByDefault || m_strFileName.isEmpty())
-                addPage(new UIWizardImportAppPageBasic1(m_fImportFromOCIByDefault));
+                addPage(new UIWizardImportAppPageBasic1(m_fImportFromOCIByDefault, m_strFileName));
             addPage(new UIWizardImportAppPageBasic2(m_strFileName));
             break;
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.cpp	(revision 91663)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.cpp	(revision 91664)
@@ -48,5 +48,7 @@
 *********************************************************************************************************************************/
 
-void UIWizardImportAppPage1::populateSources(QIComboBox *pCombo, bool fImportFromOCIByDefault)
+void UIWizardImportAppPage1::populateSources(QIComboBox *pCombo,
+                                             bool fImportFromOCIByDefault,
+                                             const QString &strSource)
 {
     /* Sanity check: */
@@ -64,5 +66,5 @@
         /* Otherwise "OCI" or "local" should be the default one: */
         if (fImportFromOCIByDefault)
-            strOldData = "OCI";
+            strOldData = strSource.isEmpty() ? "OCI" : strSource;
         else
             strOldData = "local";
@@ -157,4 +159,5 @@
 void UIWizardImportAppPage1::refreshProfileCombo(QIComboBox *pCombo,
                                                  const QString &strSource,
+                                                 const QString &strProfileName,
                                                  bool fIsSourceCloudOne)
 {
@@ -176,4 +179,6 @@
         if (pCombo->currentIndex() != -1)
             strOldData = pCombo->currentData(ProfileData_Name).toString();
+        else if (!strProfileName.isEmpty())
+            strOldData = strProfileName;
 
         /* Block signals while updating: */
@@ -190,11 +195,11 @@
                 continue;
             /* Acquire profile name: */
-            QString strProfileName;
-            if (!cloudProfileName(comProfile, strProfileName, pParent))
+            QString strCurrentProfileName;
+            if (!cloudProfileName(comProfile, strCurrentProfileName, pParent))
                 continue;
 
             /* Compose item, fill it's data: */
-            pCombo->addItem(strProfileName);
-            pCombo->setItemData(pCombo->count() - 1, strProfileName, ProfileData_Name);
+            pCombo->addItem(strCurrentProfileName);
+            pCombo->setItemData(pCombo->count() - 1, strCurrentProfileName, ProfileData_Name);
         }
 
@@ -405,6 +410,7 @@
 *********************************************************************************************************************************/
 
-UIWizardImportAppPageBasic1::UIWizardImportAppPageBasic1(bool fImportFromOCIByDefault)
+UIWizardImportAppPageBasic1::UIWizardImportAppPageBasic1(bool fImportFromOCIByDefault, const QString &strFileName)
     : m_fImportFromOCIByDefault(fImportFromOCIByDefault)
+    , m_strFileName(strFileName)
     , m_pLabelMain(0)
     , m_pLabelDescription(0)
@@ -593,4 +599,17 @@
     connect(m_pProfileInstanceList, &QListWidget::currentRowChanged,
             this, &UIWizardImportAppPageBasic1::completeChanged);
+
+    /* Parse passed full group name if any: */
+    if (   m_fImportFromOCIByDefault
+        && !m_strFileName.isEmpty())
+    {
+        const QString strProviderShortName = m_strFileName.section('/', 1, 1);
+        const QString strProfileName = m_strFileName.section('/', 2, 2);
+        if (!strProviderShortName.isEmpty() && !strProfileName.isEmpty())
+        {
+            m_strSource = strProviderShortName;
+            m_strProfileName = strProfileName;
+        }
+    }
 }
 
@@ -691,5 +710,7 @@
 {
     /* Populate sources: */
-    populateSources(m_pSourceComboBox, m_fImportFromOCIByDefault);
+    populateSources(m_pSourceComboBox,
+                    m_fImportFromOCIByDefault,
+                    m_strSource);
     /* Translate page: */
     retranslateUi();
@@ -764,4 +785,5 @@
     refreshProfileCombo(m_pProfileComboBox,
                         source(m_pSourceComboBox),
+                        m_strProfileName,
                         wizard()->isSourceCloudOne());
 
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageExpert.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageExpert.cpp	(revision 91663)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageExpert.cpp	(revision 91664)
@@ -324,4 +324,17 @@
     connect(m_pCheckboxImportHDsAsVDI, &QCheckBox::stateChanged,
             this, &UIWizardImportAppPageExpert::sltHandleImportHDsAsVDICheckBoxChange);
+
+    /* Parse passed full group name if any: */
+    if (   m_fImportFromOCIByDefault
+        && !m_strFileName.isEmpty())
+    {
+        const QString strProviderShortName = m_strFileName.section('/', 1, 1);
+        const QString strProfileName = m_strFileName.section('/', 2, 2);
+        if (!strProviderShortName.isEmpty() && !strProfileName.isEmpty())
+        {
+            m_strSource = strProviderShortName;
+            m_strProfileName = strProfileName;
+        }
+    }
 }
 
@@ -399,5 +412,7 @@
     m_pToolBox->setCurrentPage(0);
     /* Populate sources: */
-    populateSources(m_pSourceComboBox, m_fImportFromOCIByDefault);
+    populateSources(m_pSourceComboBox,
+                    m_fImportFromOCIByDefault,
+                    m_strSource);
     /* Translate page: */
     retranslateUi();
@@ -471,5 +486,6 @@
     /* If we have file name passed,
      * check if specified file contains valid appliance: */
-    if (   !m_strFileName.isEmpty()
+    if (   !m_fImportFromOCIByDefault
+        && !m_strFileName.isEmpty()
         && !wizard()->setFile(m_strFileName))
     {
@@ -513,4 +529,5 @@
     refreshProfileCombo(m_pProfileComboBox,
                         source(m_pSourceComboBox),
+                        m_strProfileName,
                         wizard()->isSourceCloudOne());
     sltHandleProfileComboChange();
Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageExpert.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageExpert.h	(revision 91663)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageExpert.h	(revision 91664)
@@ -101,4 +101,9 @@
     QString  m_strFileName;
 
+    /** Holds the cached source. */
+    QString  m_strSource;
+    /** Holds the cached profile name. */
+    QString  m_strProfileName;
+
     /** Holds the tool-box instance. */
     UIToolBox *m_pToolBox;

Index: /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.h
===================================================================
--- /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.h	(revision 91663)
+++ /trunk/src/VBox/Frontends/VirtualBox/src/wizards/importappliance/UIWizardImportAppPageBasic1.h	(revision 91664)
@@ -57,5 +57,6 @@
     /** Populates sources. */
     void populateSources(QIComboBox *pCombo,
-                         bool fImportFromOCIByDefault);
+                         bool fImportFromOCIByDefault,
+                         const QString &strSource);
 
     /** Returns current source of @a pCombo specified. */
@@ -71,4 +72,5 @@
     void refreshProfileCombo(QIComboBox *pCombo,
                              const QString &strSource,
+                             const QString &strProfileName,
                              bool fIsSourceCloudOne);
     /** Refresh profile instances. */
@@ -107,6 +109,7 @@
 
     /** Constructs 1st basic page.
-      * @param  fImportFromOCIByDefault  Brings whether we should propose import from OCI by default. */
-    UIWizardImportAppPageBasic1(bool fImportFromOCIByDefault);
+      * @param  fImportFromOCIByDefault  Brings whether we should propose import from OCI by default.
+      * @param  strFileName              Brings appliance file name. */
+    UIWizardImportAppPageBasic1(bool fImportFromOCIByDefault, const QString &strFileName);
 
 protected:
@@ -145,5 +148,12 @@
 
     /** Holds whether default source should be Import from OCI. */
-    bool  m_fImportFromOCIByDefault;
+    bool     m_fImportFromOCIByDefault;
+    /** Handles the appliance file name. */
+    QString  m_strFileName;
+
+    /** Holds the cached source. */
+    QString  m_strSource;
+    /** Holds the cached profile name. */
+    QString  m_strProfileName;
 
     /** Holds the main label instance. */